# chrome_singleton.py

from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from webdriver_manager.chrome import ChromeDriverManager

class ChromeSingleton:
    instance = None

    @classmethod
    def get_instance(cls):
        if cls.instance is None:
            chrome_path = "/chrome-profile"
            service_obj = Service(ChromeDriverManager().install())
            chrome_options = Options()
            chrome_options.add_argument(f'user-data-dir={chrome_path}')
            cls.instance = webdriver.Chrome(service=service_obj, options=chrome_options)
        return cls.instance



# chrome_manager.py
from azucar_web_driver.chrome_factory import ChromeFactory

class ChromeManager:
    def __init__(self):
        self.instances = []

    def create_new_instance(self, use_profile=False):
        new_instance = ChromeFactory.create_instance(use_profile)
        self.instances.append(new_instance)
        return new_instance

    def close_all_instances(self):
        for instance in self.instances:
            instance.quit()
        self.instances = []


# chrome_factory.py

from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from webdriver_manager.chrome import ChromeDriverManager

class ChromeFactory:
    @staticmethod
    def create_instance(use_profile=False):
        service_obj = Service(ChromeDriverManager().install())
        chrome_options = Options()

        if use_profile:
            profile_path = "/chrome-profile"
            chrome_options.add_argument(f'user-data-dir={profile_path}')
            chrome_options.add_argument('--no-sandbox')
            chrome_options.add_argument('--headless')
            chrome_options.add_argument('--disable-dev-shm-usage')
            chrome_options.add_argument('user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.113 Safari/537.36')

        return webdriver.Chrome(service=service_obj, options=chrome_options)



from setuptools import setup, find_packages

setup(
    name='azucar_web_driver',  # Nombre de tu paquete
    version='0.1',      # Versión inicial del paquete
    packages=find_packages(),  # Encuentra automáticamente todos los paquetes
    description='Automatización de navegadores con Selenium',  # Una breve descripción
    long_description=open('README.md').read(),  # Descripción larga, típicamente de un README
    long_description_content_type='text/markdown',  # Tipo de contenido de la descripción larga
    install_requires=[   # Lista de dependencias necesarias para usar tu paquete
        'attrs==23.1.0',
        'certifi==2023.11.17',
        'cffi==1.16.0',
        'charset-normalizer==3.3.2',
        'exceptiongroup==1.2.0',
        'h11==0.14.0',
        'idna==3.6',
        'outcome==1.3.0.post0',
        'packaging==23.2',
        'pycparser==2.21',
        'PySocks==1.7.1',
        'python-dotenv==1.0.0',
        'requests==2.31.0',
        'selenium==4.16.0',
        'sniffio==1.3.0',
        'sortedcontainers==2.4.0',
        'trio==0.23.2',
        'trio-websocket==0.11.1',
        'urllib3==2.1.0',
        'webdriver-manager==4.0.1',
        'wsproto==1.2.0'
    ],
    # Incluye cualquier otro parámetro relevante como author, author_email, url, etc.
)
